@@ -6,9 +6,10 @@ from pyccolo import fast
 
 
 class TraceEvent(Enum):
+    before_import = "before_import"
     init_module = "init_module"
     exit_module = "exit_module"
-    import_ = "import"
+    after_import = "after_import"
 
     before_stmt = "before_stmt"
     after_stmt = "after_stmt"
@@ -46,7 +47,8 @@ class TraceEvent(Enum):
 
     before_call = "before_call"
     after_call = "after_call"
-    argument = "argument"
+    before_argument = "before_argument"
+    after_argument = "after_argument"
     before_return = "before_return"
     after_return = "after_return"
 
@@ -123,6 +125,7 @@ SYS_TRACE_EVENTS = {
 
 
 BEFORE_EXPR_EVENTS = {
+    TraceEvent.before_argument,
     TraceEvent.before_assign_rhs,
     TraceEvent.before_augassign_rhs,
     TraceEvent.before_binop,
